using Pms.Models;
using ProjectManagementSystem.Common.Models;

namespace ProjectManagementSystem.Common.Service
{
    public interface IPmsTaskService
    {
        WebMgrResponse TaskAdd(PmsTaskInfoDto data);
        WebMgrResponse TaskAppointment(PmsTaskInfoDto data);

        WebMgrResponse ReleaseAgv(ReleaseAgvDto data);

        WebMgrResponse GetAllLocationProperty();
        WebMgrResponse UpdateLocationProperty(LocationPropertyDto data);

        ResponseResult TransportTask(RequestTransportTask taskInfo);
        ResponseResult StoreStateChange(RequestStoreStateChange data);

        ResponseData GenAgvSchedulingTask(RequestGenAgvSchedulingTask taskInfo);
    }
}